# Benchmarking functions

::: agentdojo.benchmark.benchmark_suite_with_injections

::: agentdojo.benchmark.benchmark_suite_without_injections

::: agentdojo.benchmark.run_task_with_injection_tasks

::: agentdojo.benchmark.run_task_without_injection_tasks

::: agentdojo.benchmark.SuiteResults
